netapp_ontap.models.audit_events API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.audit_events`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AuditEventsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AuditEvents object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `async_delete: bool GET POST PATCH`

    Volume file async delete events

  `audit_policy_change: bool GET POST PATCH`

    Audit policy change events

  `authorization_policy: bool GET POST PATCH`

    Authorization policy change events

  `cap_staging: bool GET POST PATCH`

    Central access policy staging events

  `cifs_logon_logoff: bool GET POST PATCH`

    CIFS logon and logoff events

  `file_operations: bool GET POST PATCH`

    File operation events

  `file_share: bool GET POST PATCH`

    File share category events

  `security_group: bool GET POST PATCH`

    Local security group management events

  `user_account: bool GET POST PATCH`

    Local user account management events